package	jp.co.sds_corp.nanchart.graph;

import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.geom.Line2D;

/**
AreaGraphは、面グラフを実装します。
*/
public class AreaGraph extends LineGraph
{
	/**
	* デフォルトの状態で面グラフを構築します。
	*/
	public AreaGraph() {
		super();
		bArea = true;
	}

	/**
	* X軸とY軸の範囲を指定して、面グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public AreaGraph( double xMin, double xMax, double yMin, double yMax ) {
		super( xMin, xMax, yMin, yMax );
		bArea = true;
	}

	/**
	* X軸とY軸の範囲を指定して、面グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public AreaGraph( Object xMin, Object xMax, Object yMin, Object yMax ) {
		super( xMin, xMax, yMin, yMax );
		bArea = true;
	}

	/**
	* データ格納クラスを指定して、面グラフを構築します。
	* @param	map		データ格納クラス
	*/
	public AreaGraph( GraphStorage map ) {
		super( map );
		bArea = true;
	}

	/**
	* グラフ描画の後処理を行ないます。
	* @param	gr		描画するデバイス
	* @param	rect	描画する矩形
	* @param	srs		描画するグラフ
	* @param	curX	現在のX座標
	* @param	curY1	現在のY座標1
	* @param	curY2	現在のY座標2
	* @param	preX	前回のX座標
	* @param	preY1	前回のY座標1
	* @param	preY2	前回のY座標2
	*/
	public void endSeries( Graphics2D gr, Rectangle rect, Object srs,
				Object curX, Object curY1, Object curY2,
				Object preX, Object preY1, Object preY2 )
	{
		Line2D line = new Line2D.Double();
		gr.setColor( LineCol );
		gr.setStroke( str );
		line.setLine( getXPos( rect, curX, curY1 ), getYPos( rect, curX, curY1 ),
					getXPos( rect, curX, curY2 ), getYPos( rect, curX, curY2 ));
		gr.draw( line );
		line.setLine( getXPos( rect, preX, preY1 ), getYPos( rect, preX, preY1 ),
					getXPos( rect, preX, preY2 ), getYPos( rect, preX, preY2 ));
		gr.draw( line );
	}

}

