package	jp.co.sds_corp.nanchart.graph;

import java.awt.Rectangle;
import java.awt.geom.Point2D;
import java.util.Iterator;
import java.util.Map;

/**
PointStorageは、散布グラフのためのデータ格納クラスです。
<BR>
このクラスでは、Integerオブジェクトがデータの順番を示し、
{@link Point2D}クラスに実際の値が格納されます。
*/
public class PointStorage extends DefaultStorage
{
	private static final long serialVersionUID = 1L;

	/**
	* デフォルトの状態でPointStorageを構築します。
	*/
	public PointStorage() {
	}

	/**
	* X軸とY軸の範囲を指定して、PointStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public PointStorage( Object xMin, Object xMax, Object yMin, Object yMax ) {
		super( xMin, xMax, yMin, yMax );
	}

	/**
	* X軸とY軸の範囲を指定して、PointStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public PointStorage( Object xMin, Object xMax, double yMin, double yMax ) {
		super( xMin, xMax, yMin, yMax );
	}

	/**
	* X軸とY軸の範囲を指定して、PointStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public PointStorage( double xMin, double xMax, double yMin, double yMax ) {
		super( xMin, xMax, yMin, yMax );
	}

	/**
	* 保持しているデータから、X軸の範囲を設定します。
	*/
	public void setXRange() {
		double		dMax = Double.NEGATIVE_INFINITY;
		Iterator	itr;
		Iterator	itrSrs;
		Map			mapKey;
		Map			mapVal;
		Object		srs;

		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	key = itr.next();
				Point2D	cur = (Point2D )mapVal.get( key );
				if ( cur == null ) {
					continue;
				}
				if ( dMax < cur.getX() ) {
					dMax = cur.getX();
				}
			}
		}
		double		dMin = Double.POSITIVE_INFINITY;
		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	key = itr.next();
				Point2D	cur = (Point2D )mapVal.get( key );
				if ( cur == null ) {
					continue;
				}
				if ( dMin > cur.getX() ) {
					dMin = cur.getX();
				}
			}
		}
		setXRange( Double.valueOf( dMin ), Double.valueOf( dMax ) );
	}

	/**
	* 保持しているデータから、Y軸の範囲を設定します。
	*/
	public void setYRange() {
		double		dMax = Double.NEGATIVE_INFINITY;
		Iterator	itr;
		Iterator	itrSrs;
		Map			mapKey;
		Map			mapVal;
		Object		srs;

		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	key = itr.next();
				Point2D	cur = (Point2D )mapVal.get( key );
				if ( cur == null ) {
					continue;
				}
				if ( dMax < cur.getY() ) {
					dMax = cur.getY();
				}
			}
		}
		double		dMin = Double.POSITIVE_INFINITY;
		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	key = itr.next();
				Point2D	cur = (Point2D )mapVal.get( key );
				if ( cur == null ) {
					continue;
				}
				if ( dMin > cur.getY() ) {
					dMin = cur.getY();
				}
			}
		}
		setYRange( Double.valueOf( dMin ), Double.valueOf( dMax ) );
	}

	/**
	* データを追加します。
	* @param	srs		系列オブジェクト
	* @param	seq		データの順番
	* @param	x		X座標を表す値
	* @param	y		Y座標を表す値
	*/
	public void add( Object srs, int seq, double x, double y ) {
		add( srs, Integer.valueOf( seq ), new Point2D.Double( x, y ));
	}

	/**
	* データを追加します。
	* @param	seq		データの順番
	* @param	x		X座標を表す値
	* @param	y		Y座標を表す値
	*/
	public void add( int seq, double x, double y ) {
		add( Integer.valueOf( seq ), new Point2D.Double( x, y ));
	}

	/**
	* X軸の値を座標値に変換します。
	* @param	rect	描画する矩形
	* @param	x		格納されているキーオブジェクト
	* @param	y		格納されている値オブジェクト
	* @return	座標値
	*/
	public double getXPos( Rectangle rect, Object x, Object y ) {
		if ( y == null ) {
			return 0.0;
		}
		return (((Point2D)y).getX() - ((Double)xMin).doubleValue() )
				/ (((Double)xMax).doubleValue() - ((Double)xMin).doubleValue() )
				* rect.getWidth() + rect.getX();
	}

	/**
	* Y軸の値を座標値に変換します。
	* @param	rect	描画する矩形
	* @param	x		格納されているキーオブジェクト
	* @param	y		格納されている値オブジェクト
	* @return	座標値
	*/
	public double getYPos( Rectangle rect, Object x, Object y ) {
		if ( y == null ) {
			return 0.0;
		}
		return rect.getHeight()
				- (((Point2D)y).getY() - ((Double)yMin).doubleValue() )
				/ (((Double)yMax).doubleValue() - ((Double)yMin).doubleValue() )
				* rect.getHeight() + rect.getY();
	}
}

