package	jp.co.sds_corp.nanchart.graph;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.geom.Line2D;
import java.awt.geom.RectangularShape;

/**
ScatterGraphは、散布グラフを実装します。
*/
public class ScatterGraph extends LineGraph
{
	/** 点の間の線の有無 */
	boolean	bLine = false;

	/**
	* デフォルトの状態で散布グラフを構築します。
	*/
	public ScatterGraph() {
		super();
		setStorage( new PointStorage() );
		setPointSize( 10 );
	}

	/**
	* X軸とY軸の範囲を指定して、散布グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public ScatterGraph( double xMin, double xMax, double yMin, double yMax ) {
		super( xMin, xMax, yMin, yMax );
		setStorage( new PointStorage( xMin, xMax, yMin, yMax ) );
		setPointSize( 10 );
	}

	/**
	* X軸とY軸の範囲を指定して、散布グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public ScatterGraph( Object xMin, Object xMax, Object yMin, Object yMax ) {
		super( xMin, xMax, yMin, yMax );
		setStorage( new PointStorage( xMin, xMax, yMin, yMax ) );
		setPointSize( 10 );
	}

	/**
	* データ格納クラスを指定して、散布グラフを構築します。
	* @param	map		データ格納クラス
	*/
	public ScatterGraph( GraphStorage map ) {
		super( map );
	}

	/**
	* 点間の線の有無を設定します。
	* @param	b		線の有無
	*/
	public void setLine( boolean b ) {
		this.bLine = b;
	}

	/**
	* 点間の線の有無を取得します。
	* @return	線の有無
	*/
	public boolean getLine() {
		return this.bLine;
	}

	/**
	* グラフ描画を行ないます。
	* @param	gr		描画するデバイス
	* @param	rect	描画する矩形
	* @param	srs		描画するグラフ
	* @param	curX	現在のX座標
	* @param	curY1	現在のY座標1
	* @param	curY2	現在のY座標2
	* @param	preX	前回のX座標
	* @param	preY1	前回のY座標1
	* @param	preY2	前回のY座標2
	*/
	public void drawPoint( Graphics2D gr, Rectangle rect, Object srs,
				Object curX, Object curY1, Object curY2,
				Object preX, Object preY1, Object preY2 )
	{
		RectangularShape	arc;
		Line2D		line = new Line2D.Double();

		if ( bLine && ( preX != null )){
			gr.setColor( LineCol );
			line.setLine( getXPos( rect, preX, preY2 ),
							getYPos( rect, preX, preY2 ),
							getXPos( rect, curX, curY2 ),
							getYPos( rect, curX, curY2 ));
			gr.draw( line );
		}

		if ( nPtSize > 0 ) {
			gr.setColor( (Color )hashPtCol.get( srs ) );
			arc = getPtShape( rect, curX, curY2 );
			gr.fill( arc );
		}
	}

}

