package	jp.co.sds_corp.nanchart.graph;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.geom.Line2D;
import java.awt.geom.RectangularShape;

/**
StairGraphは、階段グラフを実装します。
*/
public class StairGraph extends LineGraph
{
	/**
	* デフォルトの状態で階段グラフを構築します。
	*/
	public StairGraph() {
		super();
	}

	/**
	* X軸とY軸の範囲を指定して、階段グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public StairGraph( double xMin, double xMax, double yMin, double yMax ) {
		super( xMin, xMax, yMin, yMax );
	}

	/**
	* X軸とY軸の範囲を指定して、階段グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public StairGraph( Object xMin, Object xMax, Object yMin, Object yMax ) {
		super( xMin, xMax, yMin, yMax );
	}

	/**
	* データ格納クラスを指定して、階段グラフを構築します。
	* @param	map		データ格納クラス
	*/
	public StairGraph( GraphStorage map ) {
		super( map );
	}

	/**
	* グラフ描画を行ないます。
	* @param	gr		描画するデバイス
	* @param	rect	描画する矩形
	* @param	srs		描画するグラフ
	* @param	curX	現在のX座標
	* @param	curY1	現在のY座標1
	* @param	curY2	現在のY座標2
	* @param	preX	前回のX座標
	* @param	preY1	前回のY座標1
	* @param	preY2	前回のY座標2
	*/
	public void drawPoint( Graphics2D gr, Rectangle rect, Object srs,
				Object curX, Object curY1, Object curY2,
				Object preX, Object preY1, Object preY2 )
	{
		RectangularShape	arc;
		Line2D		line = new Line2D.Double();
		int			cx, cy1, cy2;
		int			px, py1, py2;

		cx  = (int)getXPos( rect, curX, null );
		cy1 = (int )getYPos( rect, curX, curY1 );
		cy2 = (int )getYPos( rect, curX, curY2 );
		if ( preX != null ) {
			px  = (int)getXPos( rect, preX, null );
			py1 = (int )getYPos( rect, preX, preY1 );
			py2 = (int )getYPos( rect, preX, preY2 );

			Color	lc = (Color )hashLineCol.get( srs );
			if ( lc == null ) {
				lc = LineCol;
			}
			gr.setColor( lc );
			line.setLine( px, py2, cx, py2 );
			gr.draw( line );
			line.setLine( cx, py2, cx, cy2 );
			gr.draw( line );
		}

		if ( nPtSize > 0 ) {
			gr.setColor( (Color )hashPtCol.get( srs ) );
			arc = getPtShape( rect, curX, curY2 );
			gr.fill( arc );
		}
	}

}

